Welcome to Oncilla 0‘s documentation! — Oncilla 0.1.0 documentation

# Welcome to Oncilla 0‘s documentation!

Contents:

- 1. Introduction
- 2. Installation
- 3. Usage
  - 3.1. Prerequisites
  - 3.2. Slicing
  - 3.3. Execution
- 4. Api
  - 4.1. oncilla.buildApi
  - 4.2. oncilla.buildTocTree
  - 4.3. oncilla.defaultSanitizer
  - 4.4. oncilla.globals.constants
  - 4.5. oncilla.reStructuredTextToHtml
  - 4.6. oncilla.sliceReStructuredText
- 5. Changes
  - 5.1. 0.1.0 - Alpha
- 6. About

# Search:

- Index
- Module Index
- Search Page